@@ -1,6 +1,6 @@
 __title__ = 'datclass'
 __author__ = 'foyoux'
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 __all__ = ['main', 'DatClass']
 
 import argparse
@@ -78,7 +78,7 @@ def get_t_string(t):
     return t.__name__
 
 
-def get_cls_name(field_name: str):
+def get_nice_cls_name(field_name: str):
     return field_name.title()
 
 
@@ -121,7 +121,7 @@ def gen_datclass(dat: Union[list, dict], name='Object', recursive=False):
         v_d = get_t_default(v_t)
         t_s = get_t_string(v_t)
         if recursive and v and (isinstance(v, dict) or t_s == 'List[dict]'):
-            s = get_cls_name(k)
+            s = get_nice_cls_name(k)
             if isinstance(v, dict):
                 t_s = s
             elif t_s == 'List[dict]':
@@ -139,18 +139,18 @@ def main():
 
     parser.add_argument('-n', '--name', help='main dat class name', default='Object')
     parser.add_argument('-r', '--recursive', help='recursive generate dat class', action='store_true')
-    parser.add_argument('-f', '--input', help='input file - likes-json')
     parser.add_argument('-o', '--output', help='output file - *.py')
+    parser.add_argument('file', nargs='?', help='input file - likes-json')
 
     args = parser.parse_args()
 
     name = args.name
     recursive = args.recursive
-    input_ = args.input
+    file = args.file
     output = args.output
 
-    if input_:
-        f = Path(input_)
+    if file:
+        f = Path(file)
         if not f.exists():
             print(f'{f.absolute()} not exists')
             return
@@ -171,7 +171,7 @@ def main():
         return
 
     dat = gen_datclass(body, name, recursive)
-    dat = imports + dat + ['']
+    dat = '\n'.join(imports + dat + [''])
 
     if output:
         f = Path(output)
